==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+54"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Chyba pri generovaní obrázkového súboru &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Obrázkový súbor bol exportovaný do &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Files</source>
        <translation>Súbory</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exportovať ako obrázok (BMP, JPG,...)</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Exportovať ako obrázok</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Rozmer</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Šírka:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Pixely na výkresovú jednotku:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Okraj:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>Pozadie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Biele</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Čierne</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>Ex&amp;portovať ako obrázok...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+78"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Chyba pri generovaní obrázkového súboru &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Obrázkový súbor bol exportovaný do &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Files</source>
        <translation>Súbory</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exportovať ako obrázok (BMP, JPG,...)</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Exportovať ako obrázok</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Rozmer</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Šírka:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Pixely na výkresovú jednotku:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Export bounding box of selection</source>
        <translation>Exportovať ohraničenie výberu</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Transparent</source>
        <translation>Priesvitné</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+23"/>
        <source>Color</source>
        <translation>Farba</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Monochrome</source>
        <translation>Čiernobiele</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Grayscale</source>
        <translation>Odtiene šedej</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Anti-aliasing</source>
        <translation>Vyhl&amp;adenie prvkov</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use anti-aliasing</source>
        <translation>Použiť vyhladzovanie hrán</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Margin</source>
        <translation>Okraj</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin:</source>
        <translation>Okraj:</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add extra margin to compensate for line weight</source>
        <translation>V prípade hrubej čiary rozšíriť okraj</translation>
    </message>
    <message>
        <location line="-170"/>
        <source>Background</source>
        <translation>Pozadie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Biele</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Čierne</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>Ex&amp;portovať ako obrázok...</translation>
    </message>
</context>
<context>
    <name>BitmapExportWorker</name>
    <message>
        <location filename="../BitmapExportWorker.js" line="+106"/>
        <source>Invalid image size (width x height must be less than %1)</source>
        <translation>Neplatná veľkosť obrazu (šírka x výška musí byť menšia ako %1)</translation>
    </message>
</context>
</TS>
